@@ -1,5 +1,5 @@
 __all__ = ('UserProfilePoint', 'UserProfileObjectPoint', 'RussianProfilePoint', 'RussianProfileObjectPoint',
-           'ProfileObjectPoint',
+           'ProfileObjectPoint', 'UserProfileIpExistsPoint',
            )
 
 from expressmoney.api import *
@@ -99,6 +99,14 @@ class RussianProfileReadContract(ProfileReadContract, ):
     fias_region = serializers.CharField(max_length=256, allow_blank=True)
 
 
+class UserProfileIpExistsCreateContract(Contract):
+    ip = serializers.IPAddressField()
+
+
+class UserProfileIpExistsResponseContract(Contract):
+    is_exist = serializers.BooleanField()
+
+
 class RussianProfileID(ID):
     _service = SERVICE
     _app = 'profiles'
@@ -117,6 +125,12 @@ class ProfileID(ID):
     _view_set = 'profile'
 
 
+class UserProfileIpExistsID(ID):
+    _service = SERVICE
+    _app = 'profiles'
+    _view_set = 'user_profile_ip_exists'
+
+
 class UserProfilePoint(CreatePointMixin, ContractPoint):
     _point_id = UserProfileID()
     _create_contract = UserProfileCreateContract
@@ -141,3 +155,9 @@ class RussianProfileObjectPoint(RetrievePointMixin, UpdatePointMixin, ContractOb
 class ProfileObjectPoint(RetrievePointMixin, ContractObjectPoint):
     _point_id = ProfileID()
     _read_contract = ProfileReadContract
+
+
+class UserProfileIpExistsPoint(ResponseMixin, CreatePointMixin, ContractPoint):
+    _point_id = UserProfileIpExistsID()
+    _create_contract = UserProfileIpExistsCreateContract
+    _response_contract = UserProfileIpExistsResponseContract
